@@ -1,8 +1,8 @@
 #' @noRd
 ################################################################################
 .fork <- function(node, x, lineages, refine = "Viterbi", nstart = 20,
-                 iterations = 50, minK = 2, maxK = 2, minscore = 0.9,
-                 probs = 0.5, retry = TRUE, resize = TRUE, maxsize = 1000,
+                 iterations = 50, minK = 2, maxK = 2, minscore = 0.95,
+                 probs = 0.5, retry = FALSE, resize = TRUE, maxsize = 1000,
                  kmers = NULL, ksize = NULL, seqweights = "Henikoff",
                  cores = 1, quiet = FALSE, verbose = FALSE, ...){
   indices <- attr(node, "sequences")
@@ -191,7 +191,7 @@
         split_node <- TRUE
         break
       }else if(nclades == maxK){
-        if(!quiet & verbose) cat("Minimum performance criteria not reached, unable to split clade\n")
+        if(!quiet & verbose) cat("Minimum performance criteria not reached, unable to split clade\n\n")
         split_node <- FALSE
         break
       }else{
